Learn R Programming

highlighter (version 0.1)

get_available_themes: Lists the current available themes

Description

List the available themes that can be used with highlighter

Usage

get_available_themes()

Arguments

Value

A character vector with the names of the themes available.